A small trial-like data set with a stronger treatment effect intended to survive simple falsifyr attack families such as row deletion, robust uncertainty checks, and drop-one covariate attacks.
A small trial-like data set with a stronger treatment effect intended to survive simple falsifyr attack families such as row deletion, robust uncertainty checks, and drop-one covariate attacks.